;; Generated package description from tuareg.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "tuareg" "3.1.10.20260626.1" "OCaml mode" '((emacs "26.3")) :commit "696fdc59e3a35cc44cd1c2d0607d782e0f0c9e71" :authors '(("Albert Cohen" . "Albert.Cohen@inria.fr") ("Sam Steingold" . "sds@gnu.org") ("Christophe Troestler" . "Christophe.Troestler@umons.ac.be") ("Till Varoquaux" . "till@pps.jussieu.fr") ("Sean McLaughlin" . "seanmcl@gmail.com") ("Stefan Monnier" . "monnier@iro.umontreal.ca")) :maintainer '(("Christophe Troestler" . "Christophe.Troestler@umons.ac.be") ("Stefan Monnier" . "monnier@iro.umontreal.ca")) :keywords '("ocaml" "languages") :url "https://github.com/ocaml/tuareg")
